cryptic

package
v0.0.0-...-03c9ee9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package cryptic provides functions for generating deterministic RSA keys and self-signed certificates.

Sub-packages for signing .jar files have been primarily sourced from the Go relic signing server.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeterministicCertificate

func DeterministicCertificate(passphrase, salt string) (*stdrsa.PrivateKey, *x509.Certificate, error)

Types

This section is empty.

Directories

Path Synopsis
Implement atomic write-rename file pattern.
Implement atomic write-rename file pattern.
A means of conveying a series of edits to binary files.
A means of conveying a series of edits to binary files.
PKCS#7 is a specification for signing or encrypting data using ASN.1 structures.
PKCS#7 is a specification for signing or encrypting data using ASN.1 structures.
PKCS#9 is a specification for trusted timestamping.
PKCS#9 is a specification for trusted timestamping.
Package rsa implements RSA encryption as specified in PKCS#1.
Package rsa implements RSA encryption as specified in PKCS#1.

Jump to